@@ -127,7 +127,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -143,13 +143,13 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_cloudfront
-import aws_cdk.aws_wafv2
-import constructs
+import aws_cdk.aws_cloudfront as _aws_cdk_aws_cloudfront_ceddda9d
+import aws_cdk.aws_wafv2 as _aws_cdk_aws_wafv2_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class WafwebaclToCloudFront(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-wafwebacl-cloudfront.WafwebaclToCloudFront",
 ):
@@ -159,12 +159,12 @@ class WafwebaclToCloudFront(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        existing_cloud_front_web_distribution: aws_cdk.aws_cloudfront.Distribution,
-        existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-        webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
+        existing_cloud_front_web_distribution: _aws_cdk_aws_cloudfront_ceddda9d.Distribution,
+        existing_webacl_obj: typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL] = None,
+        webacl_props: typing.Optional[typing.Union[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -177,16 +177,7 @@ class WafwebaclToCloudFront(
         :summary: Constructs a new instance of the WafwebaclToCloudFront class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                existing_cloud_front_web_distribution: aws_cdk.aws_cloudfront.Distribution,
-                existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-                webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d5d8bd547f935ab6b8d3616094fcce5144f3e97e2b6bc2efff5fc3b86536057b)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = WafwebaclToCloudFrontProps(
@@ -199,13 +190,15 @@ class WafwebaclToCloudFront(
 
     @builtins.property
     @jsii.member(jsii_name="cloudFrontWebDistribution")
-    def cloud_front_web_distribution(self) -> aws_cdk.aws_cloudfront.Distribution:
-        return typing.cast(aws_cdk.aws_cloudfront.Distribution, jsii.get(self, "cloudFrontWebDistribution"))
+    def cloud_front_web_distribution(
+        self,
+    ) -> _aws_cdk_aws_cloudfront_ceddda9d.Distribution:
+        return typing.cast(_aws_cdk_aws_cloudfront_ceddda9d.Distribution, jsii.get(self, "cloudFrontWebDistribution"))
 
     @builtins.property
     @jsii.member(jsii_name="webacl")
-    def webacl(self) -> aws_cdk.aws_wafv2.CfnWebACL:
-        return typing.cast(aws_cdk.aws_wafv2.CfnWebACL, jsii.get(self, "webacl"))
+    def webacl(self) -> _aws_cdk_aws_wafv2_ceddda9d.CfnWebACL:
+        return typing.cast(_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL, jsii.get(self, "webacl"))
 
 
 @jsii.data_type(
@@ -221,9 +214,9 @@ class WafwebaclToCloudFrontProps:
     def __init__(
         self,
         *,
-        existing_cloud_front_web_distribution: aws_cdk.aws_cloudfront.Distribution,
-        existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-        webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
+        existing_cloud_front_web_distribution: _aws_cdk_aws_cloudfront_ceddda9d.Distribution,
+        existing_webacl_obj: typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL] = None,
+        webacl_props: typing.Optional[typing.Union[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param existing_cloud_front_web_distribution: The existing CloudFront instance that will be protected with the WAF web ACL. This construct changes the CloudFront distribution by directly manipulating the CloudFormation output, so this must be the Construct and cannot be changed to the Interface (IDistribution)
@@ -233,20 +226,13 @@ class WafwebaclToCloudFrontProps:
         :summary: The properties for the WafwebaclToCloudFront class.
         '''
         if isinstance(webacl_props, dict):
-            webacl_props = aws_cdk.aws_wafv2.CfnWebACLProps(**webacl_props)
+            webacl_props = _aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps(**webacl_props)
         if __debug__:
-            def stub(
-                *,
-                existing_cloud_front_web_distribution: aws_cdk.aws_cloudfront.Distribution,
-                existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-                webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__40a0cf28e1b529b5efb8af1e8d3e34e9c89ef520a8810caf4b1ccce40fff2a84)
             check_type(argname="argument existing_cloud_front_web_distribution", value=existing_cloud_front_web_distribution, expected_type=type_hints["existing_cloud_front_web_distribution"])
             check_type(argname="argument existing_webacl_obj", value=existing_webacl_obj, expected_type=type_hints["existing_webacl_obj"])
             check_type(argname="argument webacl_props", value=webacl_props, expected_type=type_hints["webacl_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "existing_cloud_front_web_distribution": existing_cloud_front_web_distribution,
         }
         if existing_webacl_obj is not None:
@@ -257,7 +243,7 @@ class WafwebaclToCloudFrontProps:
     @builtins.property
     def existing_cloud_front_web_distribution(
         self,
-    ) -> aws_cdk.aws_cloudfront.Distribution:
+    ) -> _aws_cdk_aws_cloudfront_ceddda9d.Distribution:
         '''The existing CloudFront instance that will be protected with the WAF web ACL.
 
         This construct changes the CloudFront distribution by directly manipulating
@@ -266,22 +252,26 @@ class WafwebaclToCloudFrontProps:
         '''
         result = self._values.get("existing_cloud_front_web_distribution")
         assert result is not None, "Required property 'existing_cloud_front_web_distribution' is missing"
-        return typing.cast(aws_cdk.aws_cloudfront.Distribution, result)
+        return typing.cast(_aws_cdk_aws_cloudfront_ceddda9d.Distribution, result)
 
     @builtins.property
-    def existing_webacl_obj(self) -> typing.Optional[aws_cdk.aws_wafv2.CfnWebACL]:
+    def existing_webacl_obj(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL]:
         '''Existing instance of a WAF web ACL, an error will occur if this and props is set.'''
         result = self._values.get("existing_webacl_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_wafv2.CfnWebACL], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL], result)
 
     @builtins.property
-    def webacl_props(self) -> typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps]:
+    def webacl_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps]:
         '''Optional user-provided props to override the default props for the AWS WAF web ACL.
 
         :default: - Default properties are used.
         '''
         result = self._values.get("webacl_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -301,3 +291,23 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__d5d8bd547f935ab6b8d3616094fcce5144f3e97e2b6bc2efff5fc3b86536057b(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    existing_cloud_front_web_distribution: _aws_cdk_aws_cloudfront_ceddda9d.Distribution,
+    existing_webacl_obj: typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL] = None,
+    webacl_props: typing.Optional[typing.Union[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__40a0cf28e1b529b5efb8af1e8d3e34e9c89ef520a8810caf4b1ccce40fff2a84(
+    *,
+    existing_cloud_front_web_distribution: _aws_cdk_aws_cloudfront_ceddda9d.Distribution,
+    existing_webacl_obj: typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL] = None,
+    webacl_props: typing.Optional[typing.Union[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
